==> haskell-jose0.5-0.5.0.5-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-jose0.5.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jose
version: 0.5.0.5
id: jose-0.5.0.5-EqhAV2rGGEzJBAfdDREB6f
key: jose-0.5.0.5-EqhAV2rGGEzJBAfdDREB6f
license: Apache-2.0
copyright: Copyright (C) 2013, 2014, 2015, 2016  Fraser Tweedale
maintainer: frase@frase.id.au
homepage: https://github.com/frasertweedale/hs-jose
synopsis: Javascript Object Signing and Encryption and JSON Web Token library
description:
    .
    An implementation of the Javascript Object Signing and Encryption
    (JOSE) and JSON Web Token (JWT; RFC 7519) formats.
    .
    The JSON Web Signature (JWS; RFC 7515) implementation is complete.
    JSON Web Encryption (JWE; RFC 7516) is not yet implemented.
    .
    All JWS algorithms (HMAC, ECDSA, RSASSA-PKCS-v1_5 and RSASSA-PSS)
    are implemented, however, the ECDSA implementation is is
    vulnerable to timing attacks and should therefore only be used for
    JWS verification.
    .
    The '\''Crypto.JOSE.Legacy'\'' module is provided for working with the
    Mozilla Persona (formerly BrowserID) key format.  Only RSA keys
    are supported - DSA keys cannot be used and must be handled as
    opaque objects.
category: Cryptography
author: Fraser Tweedale
exposed: True
indefinite: False
exposed-modules:
    Crypto.JOSE Crypto.JOSE.Compact Crypto.JOSE.Error
    Crypto.JOSE.Header Crypto.JOSE.JWE Crypto.JOSE.JWK Crypto.JOSE.JWS
    Crypto.JOSE.Legacy Crypto.JOSE.Types Crypto.JWT
hidden-modules: Crypto.JOSE.AESKW Crypto.JOSE.JWA.JWK
                Crypto.JOSE.JWA.JWS Crypto.JOSE.JWA.JWE Crypto.JOSE.JWA.JWE.Alg
                Crypto.JOSE.JWS.Internal Crypto.JOSE.TH Crypto.JOSE.Types.Internal
                Crypto.JOSE.Types.Orphans
abi: 611b5717aa610623f70ba66e1fc30eac
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/jose-0.5.0.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/jose-0.5.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/jose-0.5.0.5
hs-libraries: HSjose-0.5.0.5-EqhAV2rGGEzJBAfdDREB6f
depends:
    base-4.10.1.0 attoparsec-0.13.2.0-GogCtb3ELCcCdy2SawxAmT
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL containers-0.5.10.2
    cryptonite-0.24-FsGdn9UZ3LaKB1k22FpT6O
    lens-4.15.4-J3dC2DI4asVJK8xmf5Ib3B
    memory-0.14.11-3SpbaRkSFfh8uo9jYloypK
    monad-time-0.2-LUGpLHgSHKFHCiGjsIZzVq
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7 template-haskell-2.12.0.0
    safe-0.3.15-EroU33EYnr02fGSZYGiX97
    aeson-1.2.3.0-D2GZ8DOS25VDM6QP4cWx4T
    unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB
    bytestring-0.10.8.2 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    time-1.8.0.2 network-uri-2.6.1.0-BbYfQUrqmQG8TYLVq3Shq8
    QuickCheck-2.10.1-BUFYQzp5Pjm7JbQeTzW89l
    quickcheck-instances-0.3.16-5H1bweGcJhO6iX7Bxkxpxy
    x509-1.7.2-DDtmfKkL6YJ4YpGfMBAKCO
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             attoparsec-0.13.2.0-GogCtb3ELCcCdy2SawxAmT=df7a760494a5e12a3c62697bd607e49b
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fd5db0dc9688093c1ac2c3223371478e
             byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL=d7caed3dfdc2cc9400ff9a46cbe7296d
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             cryptonite-0.24-FsGdn9UZ3LaKB1k22FpT6O=2a2c063fe509f8391029ab6415e03b56
             lens-4.15.4-J3dC2DI4asVJK8xmf5Ib3B=3aacb2259589d051f401cfef2f56aa6d
             memory-0.14.11-3SpbaRkSFfh8uo9jYloypK=4e89c83af85871b8cc7efa88b3351f52
             monad-time-0.2-LUGpLHgSHKFHCiGjsIZzVq=116f431f7921957b9b3eca4c6ee81af5
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7=d64b81e3ed8022aca04423ee7b330679
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=604c7b7c109a34b58d71795df287548a
             aeson-1.2.3.0-D2GZ8DOS25VDM6QP4cWx4T=0380c985bcf57973f058a04b4ba82ddf
             unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB=1ae4406c8abf6f6a305796d42b6e1b7b
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             network-uri-2.6.1.0-BbYfQUrqmQG8TYLVq3Shq8=ab32d4d3146164271ec97b5409cdba0c
             QuickCheck-2.10.1-BUFYQzp5Pjm7JbQeTzW89l=a871331a7e5e7b5c37818b7997512ddd
             quickcheck-instances-0.3.16-5H1bweGcJhO6iX7Bxkxpxy=8384691df0542f4ecba7e30435c5bfb1
             x509-1.7.2-DDtmfKkL6YJ4YpGfMBAKCO=b5ed7e5692be726b569cbfad4cafd223
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=d8375a46a4155c3f449ce3d319b3dbaa
haddock-interfaces: /usr/share/doc/haskell-jose0.5/html/jose.haddock
haddock-html: /usr/share/doc/haskell-jose0.5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-jose0.5-0.5.0.5-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-jose0.5.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: jose
version: 0.5.0.5
id: jose-0.5.0.5-Hq6UUzPrp4hHRxRJKxUEWz
key: jose-0.5.0.5-Hq6UUzPrp4hHRxRJKxUEWz
license: Apache-2.0
copyright: Copyright (C) 2013, 2014, 2015, 2016  Fraser Tweedale
maintainer: frase@frase.id.au
homepage: https://github.com/frasertweedale/hs-jose
synopsis: Javascript Object Signing and Encryption and JSON Web Token library
description:
    .
    An implementation of the Javascript Object Signing and Encryption
    (JOSE) and JSON Web Token (JWT; RFC 7519) formats.
    .
    The JSON Web Signature (JWS; RFC 7515) implementation is complete.
    JSON Web Encryption (JWE; RFC 7516) is not yet implemented.
    .
    All JWS algorithms (HMAC, ECDSA, RSASSA-PKCS-v1_5 and RSASSA-PSS)
    are implemented, however, the ECDSA implementation is is
    vulnerable to timing attacks and should therefore only be used for
    JWS verification.
    .
    The '\''Crypto.JOSE.Legacy'\'' module is provided for working with the
    Mozilla Persona (formerly BrowserID) key format.  Only RSA keys
    are supported - DSA keys cannot be used and must be handled as
    opaque objects.
category: Cryptography
author: Fraser Tweedale
exposed: True
indefinite: False
exposed-modules:
    Crypto.JOSE Crypto.JOSE.Compact Crypto.JOSE.Error
    Crypto.JOSE.Header Crypto.JOSE.JWE Crypto.JOSE.JWK Crypto.JOSE.JWS
    Crypto.JOSE.Legacy Crypto.JOSE.Types Crypto.JWT
hidden-modules: Crypto.JOSE.AESKW Crypto.JOSE.JWA.JWK
                Crypto.JOSE.JWA.JWS Crypto.JOSE.JWA.JWE Crypto.JOSE.JWA.JWE.Alg
                Crypto.JOSE.JWS.Internal Crypto.JOSE.TH Crypto.JOSE.Types.Internal
                Crypto.JOSE.Types.Orphans
abi: d67fa4cbbd3730c1323529ff4ac71bf9
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/jose-0.5.0.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/jose-0.5.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/jose-0.5.0.5
hs-libraries: HSjose-0.5.0.5-Hq6UUzPrp4hHRxRJKxUEWz
depends:
    base-4.10.1.0 attoparsec-0.13.2.0-GogCtb3ELCcCdy2SawxAmT
    base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be
    byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL containers-0.5.10.2
    cryptonite-0.24-FC0We6oYAXIECOkg9xzGYw
    lens-4.15.4-J3dC2DI4asVJK8xmf5Ib3B
    memory-0.14.12-BTp4cbdvYCLFqY2CwtLFIt
    monad-time-0.2-LUGpLHgSHKFHCiGjsIZzVq
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7 template-haskell-2.12.0.0
    safe-0.3.15-EroU33EYnr02fGSZYGiX97
    aeson-1.2.3.0-D2GZ8DOS25VDM6QP4cWx4T
    unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB
    bytestring-0.10.8.2 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    time-1.8.0.2 network-uri-2.6.1.0-BbYfQUrqmQG8TYLVq3Shq8
    QuickCheck-2.10.1-BUFYQzp5Pjm7JbQeTzW89l
    quickcheck-instances-0.3.16-5H1bweGcJhO6iX7Bxkxpxy
    x509-1.7.2-CrSAixwXTXn5v6sQH1L6fr
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             attoparsec-0.13.2.0-GogCtb3ELCcCdy2SawxAmT=df7a760494a5e12a3c62697bd607e49b
             base64-bytestring-1.0.0.1-8MlzMz2YH3lCqJ4GOwL1Be=fd5db0dc9688093c1ac2c3223371478e
             byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL=d7caed3dfdc2cc9400ff9a46cbe7296d
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             cryptonite-0.24-FC0We6oYAXIECOkg9xzGYw=26e0aefe9b0434ab51622f8141308d0b
             lens-4.15.4-J3dC2DI4asVJK8xmf5Ib3B=3aacb2259589d051f401cfef2f56aa6d
             memory-0.14.12-BTp4cbdvYCLFqY2CwtLFIt=0bbf4eba75d66590f8174b4addb225f6
             monad-time-0.2-LUGpLHgSHKFHCiGjsIZzVq=116f431f7921957b9b3eca4c6ee81af5
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7=d64b81e3ed8022aca04423ee7b330679
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             safe-0.3.15-EroU33EYnr02fGSZYGiX97=604c7b7c109a34b58d71795df287548a
             aeson-1.2.3.0-D2GZ8DOS25VDM6QP4cWx4T=0380c985bcf57973f058a04b4ba82ddf
             unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB=1ae4406c8abf6f6a305796d42b6e1b7b
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             network-uri-2.6.1.0-BbYfQUrqmQG8TYLVq3Shq8=ab32d4d3146164271ec97b5409cdba0c
             QuickCheck-2.10.1-BUFYQzp5Pjm7JbQeTzW89l=a871331a7e5e7b5c37818b7997512ddd
             quickcheck-instances-0.3.16-5H1bweGcJhO6iX7Bxkxpxy=8384691df0542f4ecba7e30435c5bfb1
             x509-1.7.2-CrSAixwXTXn5v6sQH1L6fr=a03bd78d8ef66302c689519b0d5cc7a8
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=d8375a46a4155c3f449ce3d319b3dbaa
haddock-interfaces: /usr/share/doc/haskell-jose0.5/html/jose.haddock
haddock-html: /usr/share/doc/haskell-jose0.5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
